pm4py.algo.discovery.inductive.variants.im\_d.util package
==========================================================

Submodules
----------

pm4py.algo.discovery.inductive.variants.im\_d.util.check\_skip\_trans module
----------------------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.inductive.variants.im_d.util.check_skip_trans
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.inductive.variants.im\_d.util.get\_tree\_repr\_dfg\_based module
-------------------------------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.inductive.variants.im_d.util.get_tree_repr_dfg_based
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.inductive.variants.im_d.util
   :members:
   :undoc-members:
   :show-inheritance:
